"use strict";
/*
 * Copyright Fastly, Inc.
 * Licensed under the MIT license. See LICENSE file for details.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = __importStar(require("fs"));
const constants_1 = require("./constants");
const util_1 = require("./util");
const nodejs = __importStar(require("./nodejs"));
const edge = __importStar(require("./edge"));
async function transformFunction(ctx) {
    const vcConfig = (0, util_1.loadVcConfig)(ctx.functionFilesSourcePath);
    let functionSkipReason = null;
    let runtime = null;
    if (fs.existsSync(ctx.functionFilesTargetPath)) {
        functionSkipReason = `target directory '${ctx.functionFilesTargetPath}' already exists.`;
    }
    else if (vcConfig == null) {
        functionSkipReason = 'unrecognized .vc-config.json.';
    }
    else if (vcConfig.runtime == null) {
        functionSkipReason = `.vc-config.json contains no 'runtime' value.`;
    }
    else if (vcConfig.framework == null) {
        functionSkipReason = `.vc-config.json contains no 'framework' value.`;
    }
    else if (vcConfig.framework.slug !== 'nextjs') {
        functionSkipReason = `.vc-config.json specifies 'framework.slug' other than 'nextjs': ${vcConfig.framework.slug}.`;
    }
    else if (!constants_1.COMPATIBLE_NEXT_VERSIONS.includes(vcConfig.framework.version)) {
        functionSkipReason = `.vc-config.json specifies incompatible Next.js version. Expected ${constants_1.COMPATIBLE_NEXT_VERSIONS.length > 0 ? 'one of ' : ''}${constants_1.COMPATIBLE_NEXT_VERSIONS.map(v => `'${v}'`).join(', ')}, found '${vcConfig.framework.version}'.`;
    }
    else {
        try {
            if (vcConfig.runtime === 'edge') {
                runtime = 'edge';
                edge.validateConfig(vcConfig);
            }
            else if (vcConfig.runtime.startsWith('nodejs')) {
                runtime = 'nodejs';
                nodejs.validateConfig(vcConfig);
            }
            else {
                functionSkipReason = `.vc-config.json specifies 'runtime' value other than 'edge' and 'nodejsX.XX': '${vcConfig.runtime}'.`;
            }
        }
        catch (ex) {
            if (ex instanceof Error) {
                functionSkipReason = ex.message;
            }
            else {
                throw ex;
            }
        }
    }
    if (functionSkipReason != null) {
        console.debug(`${ctx.transformName} transform: Not performing transform on '${ctx.functionPath}' - ${functionSkipReason}`);
        return false;
    }
    if (runtime === 'edge') {
        edge.doTransform(vcConfig, ctx);
        return true;
    }
    else if (runtime === 'nodejs') {
        nodejs.doTransform(vcConfig, ctx);
        return true;
    }
    return false;
}
transformFunction.transformType = 'transformFunction';
transformFunction.priority = 10;
exports.default = transformFunction;
