/*
 * Copyright Fastly, Inc.
 * Licensed under the MIT license. See LICENSE file for details.
 */
import path from 'path';
let _fsAssets = null;
let _fsSettings = null;
export function initFsAssets(contentAssets, moduleAssets) {
    _fsAssets = {
        contentAssets,
        moduleAssets,
    };
}
export function initFs(dir) {
    _fsSettings = {
        dir,
    };
}
export function getFsSettings() {
    if (_fsSettings == null) {
        throw new Error('getFsSettings called, but initFs has not been called!');
    }
    if (_fsAssets == null) {
        throw new Error('getFsSettings called, but initFsAssets has not been called!');
    }
    return {
        ..._fsSettings,
        ..._fsAssets,
    };
}
export function existsSync(dir) {
    const settings = getFsSettings();
    const fullPath = path.join(settings.dir, dir);
    return settings.contentAssets.getAsset(fullPath) != null;
}
export function resolve(...paths) {
    const settings = getFsSettings();
    return path.resolve(settings.dir, ...paths);
}
